shithub: choc

Download patch

ref: f5446def0c1df4cc00899f65331b643a75391cda
parent: ffa290d23c4a9b90341306866eb53f5a1b3f19aa
author: Simon Howard <fraggle@soulsphere.org>
date: Fri Jan 5 15:52:04 EST 2018

hexen: Change comment to American spelling.

--- a/src/hexen/p_acs.c
+++ b/src/hexen/p_acs.c
@@ -928,7 +928,7 @@
 // CheckACSPresent
 //
 // Placing Korax in a PWAD without extra steps will result in a crash in
 // Vanilla because the relevant ACS scripts are not initialised
 //
 //==========================================================================
 
@@ -936,7 +936,7 @@
 {
     if (GetACSIndex(number) == -1)
     {
-        I_Error("Required ACS script %d not initialised", number);
+        I_Error("Required ACS script %d not initialized", number);
     }
 }
@@ -928,7 +928,7 @@
 //
 // Placing Korax in a PWAD without extra steps will result in a crash in
-// Vanilla because the relevant ACS scripts are not initialised
+// Vanilla because the relevant ACS scripts are not initialized
 //
 //==========================================================================